var searchData=
[
  ['generation_0',['Registry generation',['../page_native_protocol.html#native-protocol-registry-generation',1,'']]],
  ['get_1',['get',['../structspa__dbus__connection.html#a684f175f4839121d8c976c50ca273303',1,'spa_dbus_connection']]],
  ['get_5fconnection_2',['get_connection',['../structspa__dbus__methods.html#a1e518bcb13046ec6b46a927024b6cc28',1,'spa_dbus_methods']]],
  ['get_5fcount_3',['get_count',['../structspa__cpu__methods.html#a700fe283edbd95218d18e6c5cac7f327',1,'spa_cpu_methods']]],
  ['get_5ffd_4',['get_fd',['../structspa__loop__control__methods.html#a2673d98892466d81baea852c94c91a39',1,'spa_loop_control_methods']]],
  ['get_5fflags_5',['get_flags',['../structspa__cpu__methods.html#a705910a6b831fd551b298ad64182598f',1,'spa_cpu_methods']]],
  ['get_5finterface_6',['get_interface',['../structspa__handle.html#a28e6fe4b4f4bdd29f007a1339cbe972a',1,'spa_handle']]],
  ['get_5fmax_5falign_7',['get_max_align',['../structspa__cpu__methods.html#a269e1e0cff0d3674d92b9d4935089aa8',1,'spa_cpu_methods']]],
  ['get_5fnode_8',['get_node',['../structpw__client__node__methods.html#a0d45045558276d9594008b5ac39ad404',1,'pw_client_node_methods']]],
  ['get_5fparams_9',['get_params',['../structspa__audio__aec__methods.html#a028adaf84c4fb5c19e416c53874ad57f',1,'spa_audio_aec_methods']]],
  ['get_5fpermissions_10',['get_permissions',['../structpw__client__methods.html#a7af9e64e81ebc0b3a7d726ff98e0dd84',1,'pw_client_methods']]],
  ['get_5fproxy_5ffd_11',['get_proxy_fd',['../structpw__protocol__native__ext.html#a04968e51cb5e9777795800dce3eaaa76',1,'pw_protocol_native_ext']]],
  ['get_5fregistry_12',['get_registry',['../structpw__core__methods.html#a570886edc43416b3dcd10b48016493af',1,'pw_core_methods']]],
  ['get_5fresource_5ffd_13',['get_resource_fd',['../structpw__protocol__native__ext.html#aee24b5ce6da772ce4167bfd88a8c7cdb',1,'pw_protocol_native_ext']]],
  ['get_5frt_5frange_14',['get_rt_range',['../structspa__thread__utils__methods.html#aa5a251e895f44dd6f48ee3014f0546e4',1,'spa_thread_utils_methods']]],
  ['get_5fsize_15',['get_size',['../structspa__handle__factory.html#aa48d0b857861f618011a9f4a89435484',1,'spa_handle_factory']]],
  ['get_5fvm_5ftype_16',['get_vm_type',['../structspa__cpu__methods.html#acd636f83ca2db246adfc92fc7d669204',1,'spa_cpu_methods']]],
  ['getting_20started_17',['Tutorial - Part 1: Getting Started',['../page_tutorial1.html',1,'page_tutorial']]],
  ['global_18',['Global',['../group__pw__global.html',1,'']]],
  ['global_19',['global',['../structpw__registry__events.html#a37bd7089a7a07d7154e111e67b25f96c',1,'pw_registry_events']]],
  ['global_2eh_20',['global.h',['../global_8h.html',1,'']]],
  ['global_5fadded_21',['global_added',['../structpw__context__events.html#a15e3c312ad2339ed431059d76fea5a4d',1,'pw_context_events']]],
  ['global_5fremove_22',['global_remove',['../structpw__registry__events.html#a04c4f7cbbf5dcc0c54887862887dbc97',1,'pw_registry_events']]],
  ['global_5fremoved_23',['global_removed',['../structpw__context__events.html#a8b2b69a9c179e37c9185929535a047f0',1,'pw_context_events']]],
  ['graph_24',['Graph',['../group__spa__graph.html',1,'']]],
  ['graph_25',['graph',['../page_streams.html#sec_stream_driving',1,'Driving the graph'],['../structspa__graph__node.html#a7a4bea046f4d6a88d97e12a5297ed740',1,'spa_graph_node::graph']]],
  ['graph_20scheduling_26',['Graph Scheduling',['../page_scheduling.html',1,'page_internals']]],
  ['graph_2eh_27',['graph.h',['../graph_8h.html',1,'']]],
  ['graph_5flink_28',['graph_link',['../structspa__graph__node.html#acbee04440eefb9b0a77f69ff1876dbc0',1,'spa_graph_node']]],
  ['gsettings_29',['GSettings',['../page_pulse_module_gsettings.html',1,'page_pulse_modules']]]
];
